summaryrefslogtreecommitdiff
path: root/cinder/volume/drivers/hitachi/hbsd_rest.py
diff options
context:
space:
mode:
Diffstat (limited to 'cinder/volume/drivers/hitachi/hbsd_rest.py')
-rw-r--r--cinder/volume/drivers/hitachi/hbsd_rest.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/cinder/volume/drivers/hitachi/hbsd_rest.py b/cinder/volume/drivers/hitachi/hbsd_rest.py
index 65d28c5e2..ac7eb2c86 100644
--- a/cinder/volume/drivers/hitachi/hbsd_rest.py
+++ b/cinder/volume/drivers/hitachi/hbsd_rest.py
@@ -980,11 +980,11 @@ class HBSDREST(common.HBSDCommon):
self.raise_error(msg)
def check_pool_id(self):
"""Check the pool id of hitachi_pool and hitachi_snap_pool."""
pool_id_list = []
pool_list = {'pool_list': None}
- for pool in self.conf.hitachi_pool:
+ for pool in self.conf.hitachi_pools:
pool_id_list.append(self._get_pool_id(pool_list, pool))
snap_pool = self.conf.hitachi_snap_pool
@@ -980,11 +980,11 @@ class HBSDREST(common.HBSDCommon):
self.raise_error(msg)
def check_pool_id(self):
- """Check the pool id of hitachi_pool and hitachi_snap_pool."""
+ """Check the pool id of hitachi_pools and hitachi_snap_pool."""
pool_id_list = []
pool_list = {'pool_list': None}